# Components not Working 

## QPopupEdit

It can be used but the 'save' and 'cancel' events are not propagating

## Components which use multiple panels

QStepper, QTabPanels, QCarousel

## QRadio

Use QOptionGroup instead

